==> lxqt-session_2.2.0.orig.tar.xz: lxqt-session-2.2.0/lxqt-config-session/translations/lxqt-config-session_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Muuda</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="40"/>
        <source>Search...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="54"/>
        <source>Start only in X11</source>
        <translation>Käivita vaid X11 kasutamisel</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="30"/>
        <source>Command:</source>
        <translation>Käsk:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Wait for system tray</source>
        <translation>Oota süsteemisalve laadimist</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="67"/>
        <source>Select Application</source>
        <translation>Vali rakendus</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Käivitatakse koos arvutiga</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Käivitatakse koos LXQT&apos;ga</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Asukoht: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Asendused: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="51"/>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="37"/>
        <source>Add</source>
        <translation>Lisa</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Edit</source>
        <translation>Muuda</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="23"/>
        <source>Application Autostart</source>
        <translation>Rakenduste automaatne käivitamine</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <source>Please provide Name and Command</source>
        <translation>Palun sisesta nimi ja käsk</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <source>Name should not start with dot or contain slash</source>
        <translation>Nime alguses ei tohiks olla punkti ega sees kaldkriipsu</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>„%1“ fail on juba olemas!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Põhiseadistused</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Aknahaldur</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <location filename="../basicsettings.ui" line="226"/>
        <source>Search...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt moodulid</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="81"/>
        <source>Start</source>
        <translation>Käivita teenus</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="88"/>
        <source>Stop</source>
        <translation>Peata teenus</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
        <translation>Kui kasutad Waylandit, siis kohenda skaleerimist kas komposiitori seadistustest või rakendusest kanshi.</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="114"/>
        <source>Global Screen Scaling</source>
        <translation>Keskkonnaülene ekraani skaleerimine</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="126"/>
        <source>Scale factor:</source>
        <translation>Skaleerimisfaktor:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="152"/>
        <source>Leave Session</source>
        <translation>Sessiooni lõpetamisel</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="158"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Küsi lahkumise kohta kinnitust</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="165"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Enne unnejäämist (muut- või püsimälusse salvestamist) lukusta ekraan</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="172"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Lukustuse viivitus uinumisel:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="185"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="201"/>
        <source>Use custom screen lock command</source>
        <translation>Kasuta endamääratud lukustuskäsku</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="197"/>
        <source>Select a window manager</source>
        <translation>Vali aknahaldur</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="212"/>
        <source>Select a screenlocker</source>
        <translation>Vali ekraanilukustaja</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="47"/>
        <source>Add</source>
        <translation>Lisa</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="54"/>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="23"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Keskkonnamuutujad (lisaseadistused)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="34"/>
        <source>Variable Name</source>
        <translation>Muutuja nimi</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="39"/>
        <source>Value</source>
        <translation>Väärtus</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Töötab</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt sessiooniseadistused</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Põhiseadistused</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>User Directories</source>
        <translation>Kasutaja kaustad</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Autostart</source>
        <translation>Automaatne käivitamine</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="67"/>
        <source>Wayland Settings (Experimental)</source>
        <translation>Waylandi seadistused (katseline)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="74"/>
        <source>Environment (Advanced)</source>
        <translation>Keskkonnamuutujad (lisaseadistused)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="100"/>
        <source>Session Restart Required</source>
        <translation>Palun käivita sessioon uuesti</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="101"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Mõned seadistused ei jõustu enne, kui sa sisse logid.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Sinu failide asukohad</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQt sessiooniseadistused - kasutaja kaustad</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Seadistuste rakendamisel asukohale „%1“ tekkis viga</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Vali asukoht</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Töölaud</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Allalaadimised</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Mallid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Avalikud failid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Dokumendid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Muusika</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Pildid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videod</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Sisaldab kõiki faile ja alamkaustu, mida sa näed oma töölaual</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Vaikimisi kaust allalaaditud failide salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Vaikimisi kaust mallide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Vaikimisi kaust sinu avalikult jagatavate failide ja alamkaustade jaoks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Vaikimisi kaust dokumentide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Vaikimisi kaust muusikafailide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Vaikimisi kaust pildifailide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Vaikimisi kaust videofailide hoidmiseks ja salvestamiseks</translation>
    </message>
</context>
<context>
    <name>WaylandSettings</name>
    <message>
        <location filename="../waylandsettings.ui" line="23"/>
        <source>Wayland Settings</source>
        <translation>Waylandi seadistused</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="30"/>
        <source>Wayland compositor:</source>
        <translation>Waylandi komposiitor:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="49"/>
        <location filename="../waylandsettings.ui" line="81"/>
        <source>Search...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="59"/>
        <source>Screenlock command:</source>
        <translation>Ekraanilukustuse käsk:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="71"/>
        <source>Use &quot;loginctl lock-session&quot; on kwin_wayland</source>
        <translation>Kui kasutusel on kwin_wayland, siis pruugi käsku „loginctl lock-session“</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="98"/>
        <source>Select a Wayland Compositor</source>
        <translation>Vali Waylandi komposiitor</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="103"/>
        <source>Select a Screenlocker for Wayland</source>
        <translation>Vali Waylandi puhul kasutatav ekraanilukustuse tarvik</translation>
    </message>
</context>
</TS>

==> lxqt-session_2.3.0.orig.tar.xz: lxqt-session-2.3.0/lxqt-config-session/translations/lxqt-config-session_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Muuda</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="40"/>
        <source>Search...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="54"/>
        <source>Start only in X11</source>
        <translation>Käivita vaid X11 kasutamisel</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="30"/>
        <source>Command:</source>
        <translation>Käsk:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Wait for system tray</source>
        <translation>Oota süsteemisalve laadimist</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="67"/>
        <source>Select Application</source>
        <translation>Vali rakendus</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Käivitatakse koos arvutiga</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Käivitatakse koos LXQT&apos;ga</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Asukoht: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Asendused: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="51"/>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="37"/>
        <source>Add</source>
        <translation>Lisa</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Edit</source>
        <translation>Muuda</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="23"/>
        <source>Application Autostart</source>
        <translation>Rakenduste automaatne käivitamine</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <source>Please provide Name and Command</source>
        <translation>Palun sisesta nimi ja käsk</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <source>Name should not start with dot or contain slash</source>
        <translation>Nime alguses ei tohiks olla punkti ega sees kaldkriipsu</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>„%1“ fail on juba olemas!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Põhiseadistused</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Aknahaldur</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <location filename="../basicsettings.ui" line="226"/>
        <source>Search...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt moodulid</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="81"/>
        <source>Start</source>
        <translation>Käivita teenus</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="88"/>
        <source>Stop</source>
        <translation>Peata teenus</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
        <translation>Kui kasutad Waylandit, siis kohenda skaleerimist kas komposiitori seadistustest või rakendusest kanshi.</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="114"/>
        <source>Global Screen Scaling</source>
        <translation>Keskkonnaülene ekraani skaleerimine</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="126"/>
        <source>Scale factor:</source>
        <translation>Skaleerimisfaktor:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="152"/>
        <source>Leave Session</source>
        <translation>Sessiooni lõpetamisel</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="158"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Küsi lahkumise kohta kinnitust</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="165"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Enne unnejäämist (muut- või püsimälusse salvestamist) lukusta ekraan</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="172"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Lukustuse viivitus uinumisel:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="185"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="201"/>
        <source>Use custom screen lock command</source>
        <translation>Kasuta endamääratud lukustuskäsku</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="200"/>
        <source>Select a window manager</source>
        <translation>Vali aknahaldur</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="215"/>
        <source>Select a screenlocker</source>
        <translation>Vali ekraanilukustaja</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="47"/>
        <source>Add</source>
        <translation>Lisa</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="54"/>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="23"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Keskkonnamuutujad (lisaseadistused)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="34"/>
        <source>Variable Name</source>
        <translation>Muutuja nimi</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="39"/>
        <source>Value</source>
        <translation>Väärtus</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Töötab</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt sessiooniseadistused</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Põhiseadistused</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>User Directories</source>
        <translation>Kasutaja kaustad</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Autostart</source>
        <translation>Automaatne käivitamine</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="67"/>
        <source>Wayland Settings</source>
        <translation>Waylandi seadistused</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="74"/>
        <source>Environment (Advanced)</source>
        <translation>Keskkonnamuutujad (lisaseadistused)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="100"/>
        <source>Session Restart Required</source>
        <translation>Palun käivita sessioon uuesti</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="101"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Mõned seadistused ei jõustu enne, kui sa sisse logid.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Sinu failide asukohad</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQt sessiooniseadistused - kasutaja kaustad</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Seadistuste rakendamisel asukohale „%1“ tekkis viga</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Vali asukoht</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Töölaud</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Allalaadimised</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Mallid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Avalikud failid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Dokumendid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Muusika</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Pildid</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videod</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Sisaldab kõiki faile ja alamkaustu, mida sa näed oma töölaual</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Vaikimisi kaust allalaaditud failide salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Vaikimisi kaust mallide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Vaikimisi kaust sinu avalikult jagatavate failide ja alamkaustade jaoks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Vaikimisi kaust dokumentide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Vaikimisi kaust muusikafailide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Vaikimisi kaust pildifailide hoidmiseks ja salvestamiseks</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Vaikimisi kaust videofailide hoidmiseks ja salvestamiseks</translation>
    </message>
</context>
<context>
    <name>WaylandSettings</name>
    <message>
        <location filename="../waylandsettings.ui" line="23"/>
        <source>Wayland Settings</source>
        <translation>Waylandi seadistused</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="30"/>
        <source>Wayland compositor</source>
        <translation>Waylandi komposiitor:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="49"/>
        <location filename="../waylandsettings.ui" line="81"/>
        <source>Search...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="59"/>
        <source>Screenlock command</source>
        <translation>Ekraanilukustuse käsk:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="71"/>
        <source>Use &quot;loginctl lock-session&quot; on kwin_wayland</source>
        <translation>Kui kasutusel on kwin_wayland, siis pruugi käsku „loginctl lock-session“</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="98"/>
        <source>Select a Wayland Compositor</source>
        <translation>Vali Waylandi komposiitor</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="103"/>
        <source>Select a Screenlocker for Wayland</source>
        <translation>Vali Waylandi puhul kasutatav ekraanilukustuse tarvik</translation>
    </message>
</context>
</TS>
